@@ -1,74 +1,62 @@
 import os
 import platform
 
+#pylint: disable=invalid-name
 base_dir = os.path.dirname(os.path.abspath(__file__)) + os.path.sep
 
 os_bit = platform.architecture()[0][:-3]
 
 latest_release = 'https://chromedriver.storage.googleapis.com/{}/'
 
-chromedriver_latest_release =   latest_release + "chromedriver_win32.zip" if platform.system() == 'Windows' else\
-                                latest_release + "chromedriver_linux64.zip" if platform.system() == "Linux" else\
-                                latest_release + "chromedriver_mac64_m1.zip" if 'arm' in str(os.uname().machine) and platform.system() == 'Darwin' else\
-                                latest_release + "chromedriver_mac64.zip"
-
-chromedriver_platform_release = "chromedriver.exe" if platform.system() == 'Windows' else\
-                                "chromedriver"
+chromedriver_latest_release =   "chromedriver_win32.zip" if platform.system() == 'Windows' else\
+                                "chromedriver_linux64.zip" if platform.system() == "Linux" else\
+                                "chromedriver_mac64_m1.zip" if 'arm' in str(os.uname().machine)\
+                                and platform.system() == 'Darwin' else\
+                                "chromedriver_mac64.zip"
+chromedriver_latest_release = latest_release + chromedriver_latest_release
 
 
 latest_release_geckodriver = 'https://github.com/mozilla/geckodriver/releases/download/v{}/'
-geckodriver_platform_release =  latest_release_geckodriver + "geckodriver-v{}-" + f"win{os_bit}.zip" if platform.system() == 'Windows' else\
-                                latest_release_geckodriver + "geckodriver-v{}-" + f"linux{os_bit}.tar.gz" if platform.system() == "Linux" else\
-                                latest_release_geckodriver + "geckodriver-v{}-macos-aarch64.tar.gz" if 'arm' in str(os.uname().machine) and platform.system() == 'Darwin' else\
-                                latest_release_geckodriver + "geckodriver-v{}-macos.tar.gz"
-
-geckodriver_platform_last_release = "geckodriver.exe" if platform.system() == 'Windows' else\
-                                "geckodriver"
+geckodriver_platform_release =  "geckodriver-v{}-" + f"win{os_bit}.zip" if platform.system() == 'Windows' else\
+                                "geckodriver-v{}-" + f"linux{os_bit}.tar.gz" if platform.system() == "Linux" else\
+                                "geckodriver-v{}-macos-aarch64.tar.gz" if 'arm' in str(os.uname().machine)\
+                                and platform.system() == 'Darwin' else\
+                                "geckodriver-v{}-macos.tar.gz"
+geckodriver_platform_release = latest_release_geckodriver + geckodriver_platform_release
 
 
 latest_release_operadriver = 'https://github.com/operasoftware/operachromiumdriver/releases/download/v.{}/'
-operadriver_latest_release =    latest_release_operadriver + f"operadriver_win{os_bit}.zip" if platform.system() == 'Windows' else\
-                                latest_release_operadriver + "operadriver_linux64.zip" if platform.system() == "Linux" else\
-                                latest_release_operadriver + "operadriver_mac64.zip"
-
-operadriver_platform_release = "operadriver.exe" if platform.system() == 'Windows' else\
-                                    "operadriver"
-
-operadriver_name_platform_release = f"operadriver_win{os_bit}" if platform.system() == 'Windows' else\
-                                    "operadriver_linux64" if platform.system() == "Linux" else\
-                                    "operadriver_mac64"
-
-
+operadriver_latest_release =    f"operadriver_win{os_bit}.zip" if platform.system() == 'Windows' else\
+                                "operadriver_linux64.zip" if platform.system() == "Linux" else\
+                                "operadriver_mac64.zip"
+operadriver_latest_release = latest_release_operadriver + operadriver_latest_release
 
 latest_release_edgedriver = 'https://msedgedriver.azureedge.net/{}/'
-edgedriver_latest_release =     latest_release_edgedriver + f"edgedriver_win{os_bit}.zip" if platform.system() == 'Windows' else\
-                                latest_release_edgedriver + "edgedriver_mac64.zip" if platform.system() == 'Darwin' else\
-                                latest_release_edgedriver + "edgedriver_linux64" if platform.system() == 'Linux' else\
-                                latest_release_edgedriver + "edgedriver_arm64.zip"
-                                
-edgedriver_platform_release =  "msedgedriver.exe" if platform.system() == 'Windows' else\
-                             "msedgedriver"
+edgedriver_latest_release =     f"edgedriver_win{os_bit}.zip" if platform.system() == 'Windows' else\
+                                "edgedriver_mac64.zip" if platform.system() == 'Darwin' else\
+                                "edgedriver_linux64" if platform.system() == 'Linux' else\
+                                "edgedriver_arm64.zip"
+edgedriver_latest_release = latest_release_edgedriver + edgedriver_latest_release
+
 
 url_release_phantomjs = "https://api.bitbucket.org/2.0/repositories/ariya/phantomjs/downloads/"
 os_bit_linux = 'x86_64' if os_bit == '64' else "i686"
-phantomjs_latest_release =      url_release_phantomjs + "phantomjs-{}-windows.zip" if platform.system() == 'Windows' else\
-                                url_release_phantomjs + "phantomjs-{}-linux-{}.tar.bz2".format({}, os_bit_linux) if platform.system() == "Linux" else\
-                                url_release_phantomjs + "phantomjs-{}-macosx.zip"
-
-phantomjs_platform_release = "phantomjs.exe" if platform.system() == 'Windows' else\
-                                "phantomjs"
-
+phantomjs_latest_release =  "phantomjs-{}-windows.zip" if platform.system() == 'Windows' else\
+                            "phantomjs-{}-" + f"linux-{os_bit_linux}.tar.bz2" if platform.system() == "Linux" else\
+                            "phantomjs-{}-macosx.zip"
+phantomjs_latest_release = url_release_phantomjs + phantomjs_latest_release
 
 #
 # BROWSERS AND THEIR UPDATERS
 #                                 
 
-chrome_browser_path = '/Applications/Google Chrome.app/Contents/MacOS/Google Chrome' if platform.system() == 'Darwin' else \
+chrome_browser_path = ['/Applications/Google Chrome.app/Contents/MacOS/Google Chrome',
+"/Applications/Chromium.app/Contents/MacOS/Chromium"] if platform.system() == 'Darwin' else \
 ['reg query "HKEY_CURRENT_USER\Software\Google\Chrome\BLBeacon" /v version',
 r'reg query "HKEY_LOCAL_MACHINE\SOFTWARE\WOW6432Node\Microsoft\Windows\CurrentVersion\Uninstall\Google Chrome" /v version'] if platform.system() == 'Windows' else \
 "google-chrome-stable" if platform.system() == 'Linux' else ''
 
-chrome_browser_updater = r'"C:\Program Files (x86)\Google\Update\GoogleUpdate.exe"' if platform.system() == 'Windows' else \
+chrome_browser_updater = r'"C:\Program Files (x86)\Google\Update\GoogleUpdate.exe" /ua /installsource scheduler' if platform.system() == 'Windows' else \
 'open "/Library/Google/GoogleSoftwareUpdate/GoogleSoftwareUpdate.bundle/Contents/Helpers/GoogleSoftwareUpdateAgent.app"' if platform.system() == 'Darwin' else\
 "sudo apt-get install google-chrome-stable" if platform.system() == 'Linux' else ''
 
@@ -78,7 +66,8 @@ chrome_browser_updater_path = r"C:\Program Files (x86)\Google\Update\GoogleUpdat
 
 firefox_browser_path = '/Applications/Firefox.app/Contents/MacOS/firefox' if platform.system() == 'Darwin' else \
 ['reg query "HKEY_CURRENT_USER\Software\Mozilla\Mozilla Firefox" /v CurrentVersion',
-'reg query "HKEY_LOCAL_MACHINE\SOFTWARE\Mozilla\Mozilla Firefox" /v CurrentVersion'] if platform.system() == 'Windows' else\
+'reg query "HKEY_LOCAL_MACHINE\SOFTWARE\Mozilla\Mozilla Firefox" /v CurrentVersion',
+r"Powershell (Get-Item (Get-ItemProperty 'HKLM:\SOFTWARE\Microsoft\Windows\CurrentVersion\App Paths\firefox.exe').'(Default)').VersionInfo.ProductVersion"] if platform.system() == 'Windows' else\
 "firefox" if platform.system() == 'Linux' else ''
 
 firefox_browser_updater = r'"C:\Program Files\Mozilla Firefox\updater.exe"' if platform.system() == 'Windows' else \
@@ -121,7 +110,7 @@ from dataclasses import dataclass
 
 @dataclass
 class info:
-    version = "4.0.2"
+    version = "5.0.1"
 
 setting = dict(
     {
@@ -133,30 +122,28 @@ setting = dict(
             'DriversFileFormat'         : ".exe" if platform.system() == 'Windows' else '',
         },
         "ChromeDriver":
-        {   
+        {
             "LinkLastRelease"                   : "https://chromedriver.storage.googleapis.com/LATEST_RELEASE",
             "LinkLastReleaseFile"               : chromedriver_latest_release,
-            "LastReleasePlatform"               : chromedriver_platform_release,
+            "LastReleasePlatform"               : 'chromedriver',
             "LinkLatestReleaseSpecificVersion"  : "https://chromedriver.storage.googleapis.com/LATEST_RELEASE_{}",
             "LinkCheckVersionIsValid"           : "https://chromedriver.storage.googleapis.com/?delimiter=/&prefix={}/",
         },
         "GeckoDriver":
         {
-            "LinkLastRelease"           : 'https://api.github.com/repos/mozilla/geckodriver/releases/latest',
             "LinkLastReleasePlatform"   : geckodriver_platform_release,
-            "LastReleasePlatform"       : geckodriver_platform_last_release,
+            "LastReleasePlatform"       : 'geckodriver',
         },
         "OperaDriver":
         {
-            "LinkLastRelease"           : 'https://api.github.com/repos/operasoftware/operachromiumdriver/releases/latest',
-            "LinkLastReleasePlatform"   : operadriver_latest_release, 
-            "LastReleasePlatform"       : operadriver_platform_release, 
+            "LinkLastReleasePlatform"   : operadriver_latest_release,
+            "LastReleasePlatform"       : 'operadriver',
         },
         "EdgeDriver":
         {
             "LinkLastRelease"                   : 'https://msedgewebdriverstorage.blob.core.windows.net/edgewebdriver/LATEST_STABLE',
-            "LinkLastReleaseFile"               : edgedriver_latest_release, 
-            "LastReleasePlatform"               : edgedriver_platform_release,
+            "LinkLastReleaseFile"               : edgedriver_latest_release,
+            "LastReleasePlatform"               : 'msedgedriver',
             "LinkCheckVersionIsValid"           : "https://msedgewebdriverstorage.blob.core.windows.net/edgewebdriver?prefix={}%2F&delimiter=%2F&maxresults=100&restype=container&comp=list&_=1622714933676&timeout=60000",
             "LinkLatestReleaseSpecificVersion"  : "https://msedgewebdriverstorage.blob.core.windows.net/edgewebdriver/LATEST_RELEASE_{}",
         },
@@ -165,11 +152,16 @@ setting = dict(
             'ChromiumChromeDriverUpdater'    : chromiumchromedriver_updater,
         },
         "PhantomJS":
-        {   
+        {
             "LinkLastReleaseFile"   : phantomjs_latest_release,
-            "LastReleasePlatform"   : phantomjs_platform_release,
+            "LastReleasePlatform"   : 'phantomjs',
             "LinkAllReleases"       : url_release_phantomjs,
         },
+        "SafariDriver":
+        {   
+            "LinkLastRelease"       : 'https://support.apple.com/en-us/HT201222',
+            "LastReleasePlatform"   : 'safaridriver',
+        },
         "ChromeBrowser":
         {
             "Path"                      : chrome_browser_path,
@@ -194,8 +186,7 @@ setting = dict(
         "OperaBrowser":
         {
             "Path"                          : opera_browser_path,
-            'LinkAllReleases'               : 'https://blogs.opera.com/desktop/?s=Stable+update',
-            "LinkSpecificReleaseChangelog"  : 'https://blogs.opera.com/desktop/changelog-for-{}/',
+            "LinkAllLatestRelease"          : 'https://get.geo.opera.com/pub/opera/desktop/',
             "OperaBrowserUpdater"           : opera_browser_updater,
             'OperaBrowserUpdaterPath'       : opera_browser_updater_path,
         },
